# unittest-extensions
Extension of Python's standard unittest library

# Introduction
If testing is not easy, you will not do it.  
If you do not test, bad things will happen.  
Thus, if testing is not easy bad things will happen.  

This minimal library aims to simplify behavioural testing with Python's standard
 [`unittest`](https://docs.python.org/3/library/unittest.html) library by separating
 object and data creation from behaviour assertion. Furthermore, it is intended to serve users that want to write really small test functions where what is being asserted is quickly comprehended and easily visible.  
   
`unittest-extensions` is mainly inspired by Ruby's [`RSpec`](https://rspec.info/) framework.

# Installation
```
pip install unittest-extensions
```
# Usage


# License
[MIT License](https://opensource.org/license/mit/)